single_word_parser_keywords

Function single_word_parser_keywords 

pub fn single_word_parser_keywords() -> impl Iterator<Item = &'static str>
Single-token parser keyword names that cannot be used as command or alias names.

Multi-word entries (export def, overlay use, …) are omitted because they cannot appear as a single definition name token.